﻿using Amazon.DynamoDBv2;
using Amazon.DynamoDBv2.Model;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;

namespace DynamoDbLocalUse.Controllers
{
    public class DynamoDBController : Controller
    {
        private const string TableName1 = "CarCatalog";

        private readonly IAmazonDynamoDB _amazonDynamoDB;
        private IWebHostEnvironment _hostingEnvironment;
        public DynamoDBController(IAmazonDynamoDB amazonDynamoDB, IWebHostEnvironment environment)
        {
            _amazonDynamoDB = amazonDynamoDB;
            _hostingEnvironment = environment;
        }

        public async Task<ActionResult<string>> InitializeTable()
        {
            // przygotowanie żądania utworzenia tabeli wraz z definicją klucza głównego 
            // oraz wartości read/write capacities
            var request = new CreateTableRequest
            {
                TableName = TableName1,
                AttributeDefinitions = new List<AttributeDefinition>()
                {
                    new AttributeDefinition()
                    {
                        AttributeName = "Id",
                        AttributeType = "N"
                    }
                },
                KeySchema = new List<KeySchemaElement>() {
                    new KeySchemaElement()
                    {
                        AttributeName = "Id",
                        KeyType = "Hash" // Partition key
                    }

                },
                ProvisionedThroughput = new ProvisionedThroughput()
                {
                    ReadCapacityUnits = 15,
                    WriteCapacityUnits = 10
                }
            };

            var response = await _amazonDynamoDB.CreateTableAsync(request);

            var tableDescription = response.TableDescription;

            StringBuilder sb = new StringBuilder();
            sb.AppendLine($"{tableDescription.TableName} : {tableDescription.TableStatus}, " +
                $"ReadCapacity: {tableDescription.ProvisionedThroughput.ReadCapacityUnits}," +
                $"WriteCapacity: {tableDescription.ProvisionedThroughput.WriteCapacityUnits}");

            return sb.ToString();
        }
    }
}
